@@ -37,7 +37,9 @@ TunerFromOptimizer = R6Class("TunerFromOptimizer",
         # class anymore and OptimInstance would not ensure that we are in the
         # scope of mlr3tuning
         assert_multi_class(inst, c("TuningInstanceSingleCrit", "TuningInstanceMultiCrit"))
-        private$.optimizer$optimize(inst)
+        res = private$.optimizer$optimize(inst)
+        if (!inst$objective$keep_hotstart_stack) inst$objective$hotstart_stack = NULL
+        res
       }
     ),
 
